@@ -4,8 +4,8 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: A Perl Mail Authentication Milter
-our $VERSION = '2.20201208.2'; # VERSION
-use base 'Mail::Milter::Authentication::Net::ServerPatches';
+our $VERSION = '2.20201209.2'; # VERSION
+use base 'Net::Server::PreFork';
 use Mail::Milter::Authentication::Handler;
 use Mail::Milter::Authentication::Metric;
 use Mail::Milter::Authentication::Protocol::Milter;
@@ -1151,7 +1151,7 @@ Mail::Milter::Authentication - A Perl Mail Authentication Milter
 
 =head1 VERSION
 
-version 2.20201208.2
+version 2.20201209.2
 
 =head1 SYNOPSIS
 
